We no longer support installation from `pip`, and instead recommend cloning the repository locally.

Visit [our GitHub repository](https://github.com/OpenInterpreter/01/) for more information.

*The 01 is an open-source voice interface for desktop, mobile, and ESP32 chips.*